<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// ľܸƤӽФ줿exit
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslPreCheck') ) {

	/**
	 * awsslPreCheck
	 * 
	 * @param void
	 * @return void
	 */
	function awsslPreCheck() {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );

		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {
		
			//*************************************************************************/
			// ⥸塼ܾ
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );
			$current_url = $Anywheressl->getCurrentUrl();

			//*************************************************************************/
			// ɺѤߤåԤ
			//*************************************************************************/
			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;

			//*************************************************************************/
			// SSLȽѥåΥåȤԤ
			//*************************************************************************/
			$Anywheressl->setSecureCookie();

			//*************************************************************************/
			// åͭʤ顢ɺѤߤݤȽԤ
			//*************************************************************************/
			if ( ! empty($_COOKIE) || ini_get('session.use_only_cookies') !== '1' ) {
				//*********************************************************************/
				// ɺѤߤǤʤ硢̤
				//*********************************************************************/
				if ( ! $awssl_loaded ) {
					//*****************************************************************/
					// ΤߡXOOPS_ROOT_PATH/include/checklogin.phpinclude
					//*****************************************************************/
					if ( ($_SERVER['SCRIPT_FILENAME'] === XOOPS_ROOT_PATH .'/user.php') &&
						($_SERVER['REQUEST_METHOD'] === 'POST') &&
						(!empty($_POST['op']) && $_POST['op'] === 'login') ) {
						include_once( XOOPS_ROOT_PATH.'/include/checklogin.php' );
						exit;
					}
					header( "Location: " .$current_url );
				}
			}

			//*************************************************************************/
			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
			//*************************************************************************/
			$session_regenerate_id = ( $awssl_config['session_regenerate_id']['conf_value'] === 'yes' ) ? true : false;
			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );

			//*************************************************************************/
			// 
			//*************************************************************************/
			// Хåե󥰽ؿΥեɤ߹
			require_once( dirname(__FILE__) .'/buffering.inc.php' );
			// SSL-Loginοƥɥν񤭴
			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
				ob_start( 'awsslLoginPhpBuf' );
			}
			// SSL/SSLURL񤭴xoops_redirectν񤭴
			ob_start( 'awsslDefaultBuf' );

			//*************************************************************************/
			// (XOOPS_URL/admin.php)ξΤߡ֥åƱͤνԤ
			//*************************************************************************/
			if ( $current_url === XOOPS_URL .'/admin.php' ) {
				include_once( $mod_path .'/blocks/anywheressl.php' );
				show_anywheressl_block();
			}
		}
	}

	awsslPreCheck();

}

?>